@@ -26,7 +26,6 @@ def register_definition(
 			nullable=False,
 			is_internal=False,
 			rules=[],
-			transforms=[],
 			meta=None,
 			dependency_resolver=None
 		):
@@ -45,7 +44,6 @@ def register_definition(
 			nullable=nullable,
 			is_internal=is_internal,
 			rules=rules,
-			transforms=transforms,
 			meta=meta,
 			dependency_resolver=dependency_resolver
 		)
