@@ -91,10 +91,12 @@ class DefaultComponentNameStrategy(NameStrategy):
 			return class_name[:match.start] + suffix
 		return class_name + suffix
 
-	def create_name(self, definition, suffix='Model'):
+	def create_name(self, definition, suffix='Model', display_name=None):
 		if definition.is_object():
 			return definition.meta.schema_name
 		if definition.is_array():
 			return definition.data_format
-		result = DefaultComponentNameStrategy.create_component_name(definition.name, suffix)
+		if display_name is None:
+			display_name = definition.name
+		result = DefaultComponentNameStrategy.create_component_name(display_name, suffix)
 		return result
\ No newline at end of file
