@@ -1,4 +1,4 @@
-from cro_validate.enum import DataType, SchemaOutputTarget
+from cro_validate.enum import DataType
 import cro_validate.classes.definition_classes as Definitions
 from cro_validate.classes.configuration_classes import Config
 import cro_validate.classes.parameter_classes as Parameters
@@ -8,16 +8,17 @@ class Schema:
 	def __init__(
 				self,
 				model,
-				output_target=SchemaOutputTarget.Self,
 				allow_unknown_fields=False,
 				display_name=None,
 				case_sensitive=True
 			):
-		self.model = model
-		if isinstance(self.model, type):
+		if isinstance(model, type):
 			self.model = model()
+		elif isinstance(model, str):
+			self.model = Definitions.Index.get(model).data_format.model
+		else:
+			self.model = model
 		self.model_name = self.model.__class__.__name__
-		self.output_target = output_target
 		self.allow_unknown_fields = allow_unknown_fields
 		self.display_name = display_name
 		self.case_sensitive = case_sensitive
@@ -50,28 +51,15 @@ class Validator:
 		normalized = value
 		if isinstance(value, dict):
 			normalized = Parameters.Index(value)
-		if self.output_target is SchemaOutputTarget.Self:
-			'''
-			HACK: model_target shouldn't exist here.
-			Some objs are mangled by an underlying lib (dangling __dict__ entries). Must target objs for overlay instead
-			of filtering attrs. This disables SchemaOutputTarget.Parent for objs, but we don't have use cases for that
-			now so deferring.
-			'''
-			model_target = None
-			if not isinstance(value, dict):
-				model_target = value
-			model_result = self.model_validator(model_target, fqn, field_name, definition, normalized)
-			results[field_name] = model_result
-		elif self.output_target is SchemaOutputTarget.Parent:
-			model_result = self.model_validator(None, fqn, field_name, definition, normalized)
-			results.update(model_result)
+		model_target = None
+		if not isinstance(value, dict):
+			# Get the original ref back
+			model_target = value
+		model_result = self.model_validator(model_target, fqn, field_name, definition, normalized)
+		results[field_name] = model_result
 
-		else:
-			raise Config.exception_factory.create_internal_error(self.name, 'Invalid schema output configured: {0}'.format(self.output_target))
-
-	def __init__(self, name, output_target, model_validator):
+	def __init__(self, name, model_validator):
 		self.name = name
-		self.output_target = output_target
 		self.model_validator = model_validator
 
 	def __call__(self, results, fqn, field_name, definition, value, dependent_values):
